@@ -1,10 +1,10 @@
 from __future__ import annotations
 
-import logging
 import re
 from itertools import chain
 from typing import TYPE_CHECKING, Iterable
 
+from ada.config import get_logger
 from ada.core.utils import Counter, roundoff
 from ada.fem import ConnectorSection, FemSection
 from ada.fem.containers import FemSections
@@ -18,7 +18,10 @@ part_name_counter = Counter(1, "Part")
 _re_in = re.IGNORECASE | re.MULTILINE | re.DOTALL
 
 if TYPE_CHECKING:
-    from ada.concepts.levels import FEM, Assembly
+    from ada.concepts.spatial import Assembly
+    from ada.fem import FEM
+
+logger = get_logger()
 
 
 def get_sections_from_inp(bulk_str, fem: FEM) -> FemSections:
@@ -122,7 +125,8 @@ def get_beam_sections_from_inp(bulk_str: str, fem: FEM) -> Iterable[FemSection]:
             )
             return Section(profile_name, "GENBEAM", genprops=genprops, parent=fem)
         else:
-            raise ValueError(f'Currently unsupported section type "{sec_type}"')
+            logger.error(f'Currently unsupported section type "{sec_type}". Will return None')
+            return None
 
     def grab_beam(match):
         d = match.groupdict()
@@ -135,6 +139,8 @@ def get_beam_sections_from_inp(bulk_str: str, fem: FEM) -> Iterable[FemSection]:
         section_type = d["sec_type"]
         geo_props = d["line1"]
         sec = interpret_section(profile_name, section_type, geo_props)
+        if sec is None:
+            return None
         beam_y = [float(x.strip()) for x in d["line2"].split(",") if x.strip() != ""]
         metadata = dict(
             temperature=temperature,
@@ -156,7 +162,7 @@ def get_beam_sections_from_inp(bulk_str: str, fem: FEM) -> Iterable[FemSection]:
             parent=fem,
         )
 
-    return map(grab_beam, cards.re_beam.finditer(bulk_str))
+    return filter(lambda x: x is not None, map(grab_beam, cards.re_beam.finditer(bulk_str)))
 
 
 def get_solid_sections_from_inp(bulk_str, fem: FEM):
@@ -203,7 +209,7 @@ def get_shell_section(m, sh_name, fem: "FEM", a: "Assembly"):
     offset = d["offset"]
     if offset is not None:
         # TODO: update this with the latest eccentricity class
-        logging.warning("Offset for Shell elements is not yet evaluated")
+        logger.warning("Offset for Shell elements is not yet evaluated")
         for el in elset.members:
             el.eccentricity = Eccentricity(sh_ecc_vector=offset)
     int_points = d["int_points"]
